@@ -105,6 +105,8 @@ TEST_F(OpendalBddTest, FeatureTest)
     opendal_result_writer_write w = opendal_writer_write(writer.writer, &data);
     EXPECT_EQ(w.error, nullptr);
     EXPECT_EQ(w.size, this->content.length());
+    opendal_error *close_err = opendal_writer_close(writer.writer);
+    EXPECT_EQ(close_err, nullptr);
     opendal_writer_free(writer.writer);
 
     // The blocking file "test" must have content "Hello, World!" and read into buffer
